@@ -323,7 +323,7 @@ update.meta <- function(object,
   ##
   RR.Cochrane <- replacemiss(RR.Cochrane, object$RR.cochrane)
   Q.Cochrane <- replacemiss(Q.Cochrane, TRUE)
-  if (Q.Cochrane & method.tau != "DL")
+  if (Q.Cochrane & (!(sm %in% c("OR", "RR", "RD")) | method.tau != "DL"))
     Q.Cochrane <- FALSE
   ##
   model.glmm <- replacemiss(model.glmm)
